#[repr(C)]pub enum DspITEcho {
WetDryMix = 0,
FeedBack = 1,
LeftDelay = 2,
RightDelay = 3,
PanDelay = 4,
}Expand description
Parameter types for the FMOD_DSP_TYPE_ITECHO filter.
This is effectively a software based echo filter that emulates the DirectX DMO echo effect.
Impulse tracker files can support this, and FMOD will produce the effect on ANY platform, not
just those that support DirectX effects!
Used with Dsp::set_parameter and
Dsp::get_parameter
Variants
WetDryMix = 0
Ratio of wet (processed) signal to dry (unprocessed) signal. Must be in the range from 0.0 through 100.0 (all wet). The default value is 50.
FeedBack = 1
Percentage of output fed back into input, in the range from 0.0 through 100.0. The default value is 50.
LeftDelay = 2
Delay for left channel, in milliseconds, in the range from 1.0 through 2000.0. The default value is 500 ms.
RightDelay = 3
Delay for right channel, in milliseconds, in the range from 1.0 through 2000.0. The default value is 500 ms.
PanDelay = 4
Value that specifies whether to swap left and right delays with each successive echo. The default value is zero, meaning no swap. Possible values are defined as 0.0 (equivalent to FALSE) and 1.0 (equivalent to TRUE). CURRENTLY NOT SUPPORTED.